@@ -32,7 +32,7 @@ class Sentiment(ClassifierI):
 def find_features(document):
     words = word_tokenize(document)
     features = {}
-    k = open('all_words.pickle','rb')
+    k = open('sentiment/all_words.pickle','rb')
     all_words = pickle.load(k)
     k.close()
     all_words = nltk.FreqDist(all_words)
@@ -48,7 +48,7 @@ def load_model(file_path):
     return classifier
 
 def sentiment(text):
-    MNB_Clf = load_model('MNB_clf.pickle')
+    MNB_Clf = load_model('sentiment/MNB_clf.pickle')
     ensemble_clf = Sentiment(MNB_Clf) 
     feats = find_features(text)
     return ensemble_clf.classify(feats), ensemble_clf.confidence(feats)
